@@ -22,40 +22,53 @@ c
       real*8  ztrunc, rmg, rmgmax
       real*8  clen2thick, erg
       integer jcut
+c^^^^^^^^^^^
+c       to contorl rv by cqUHookr
+c      real*8 rv
+c      logical first/.true./
+c      save first
+c      if(first) then
+c         first = .false.
+c         call cqUHookr(1, rv)
+c      endif
+c^^^^^^^^^^^
 
       erg = TrackBefMove.p.fm.p(4)
 c             fix energy dependent truncation path
       if(TrackBefMove.p.charge .ne. 0) then
 
 c          magnetic
-
          call cmagDefR(TrackBefMove, Mag,  rmg)  ! get radius approx.
-         rmg = rmg/5.  !  this is almost streight movable
+          rmg = rmg/10.d0  !  this is almost streight movable
+c^^^^^^^^^
+c        rmg = rmg/rv
+c^^^^^^^^
+
 c            get max length within which B is almost const
 ccc         if(Reverse .ne. 0 .or.
 ccc     *   (erg .gt. MagBremEmin .and. MagBrem .ne. 0 )) then
 c            length within which dB  < 1 %.
-            call clengSmallBC(TrackBefMove, rmgmax)  
-            rmg = min(rmg, rmgmax)
+         call clengSmallBC(TrackBefMove, rmgmax)  
+         rmg = min(rmg, rmgmax)
 cc         endif
 
 c            mul. scatt and lpm
 
          if(Reverse .eq. 0) then
 ccc            if(TrackBefMove.pos.height .lt. AlmostVacH) then
-               call cmaxCasLen(TrackBefMove, ztrunc)
-               if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
+            call cmaxCasLen(TrackBefMove, ztrunc)
+            if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
      *         .and. LpmEffect) then
-                  ztrunc = min(TrackBefMove.pos.depth/10., ztrunc)
-               endif
-               call cthick2len(TrackBefMove.pos.height, 
+               ztrunc = min(TrackBefMove.pos.depth/10., ztrunc)
+            endif
+            call cthick2len(TrackBefMove.pos.height, 
      *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
 c                 thick may have been changed to shorter one.
-               if(rmg .lt. leng) then
-                  thick = clen2thick(TrackBefMove.pos.height,
-     *             TrackBefMove.vec.coszenith, rmg)
-                  leng = rmg
-               endif
+            if(rmg .lt. leng) then
+               thick = clen2thick(TrackBefMove.pos.height,
+     *              TrackBefMove.vec.coszenith, rmg)
+               leng = rmg
+            endif
 cc            else
 cc               thick = AlmostVacT
 cc               leng = rmg
